@@ -5,7 +5,7 @@
 
     path.to.start.GUI <- system.file("shiny", "GUI", "startGUI.r", package = "RALSA")
 
-    packageStartupMessage("\nWelcome to RALSA!\n\nFor news, help, and requests, please visit http://ralsa.ineri.org/\n")
+    packageStartupMessage("\nWelcome to RALSA!\n\nFor news, help, and requests, please visit https://ralsa.ineri.org/\n")
 
     switch(
       menu(choices = c("Yes, start now", "No, not at this time"),
